## Description

<!-- Provide a brief description of your changes -->

## Type of Change

<!-- Mark with an 'x' all that apply -->

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)
- [ ] Performance improvement
- [ ] Test coverage improvement

## Related Issues

<!-- Link to related issues (e.g., Fixes #123, Relates to #456) -->

Fixes #

## Changes Made

<!-- List the main changes -->

-
-
-

## Testing

<!-- Describe the tests you ran to verify your changes -->

- [ ] All existing tests pass (`pytest`)
- [ ] Added new tests for new functionality
- [ ] Tested on multiple platforms (if applicable)
- [ ] Manual testing completed

### Test Platform(s)

<!-- Check all that apply -->

- [ ] macOS
- [ ] Linux (Ubuntu/Debian)
- [ ] Windows

## Checklist

- [ ] My code follows the style guidelines of this project
- [ ] I have performed a self-review of my code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published

## Screenshots (if applicable)

<!-- Add screenshots to help explain your changes -->

## Additional Context

<!-- Add any other context about the PR here -->
